/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2008 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.system.action;

import jp.mosp.common.action.MosPAction;
import jp.mosp.common.common.MospConst;
import jp.mosp.common.common.MospException;
import jp.mosp.common.common.MospUtility;

import jp.mosp.system.dao.MCodeDao;
import jp.mosp.system.dto.MCodeDto;
import jp.mosp.system.vo.CodeMasterCardVo;

public class CodeMasterCardAction extends MosPAction {

	// R}h
	private static final String CMD_CODE_CARD_SHOW   = "S2305";	// \(ǉ)
	private static final String CMD_CODE_CARD_SELECT = "S2306";	// \(I)
	private static final String CMD_CODE_CARD_INSERT = "S2307";	// o^
	private static final String CMD_CODE_CARD_UPDATE = "S2308";	// XV
	private static final String CMD_CODE_CARD_DELETE = "S2309";	// 폜

	/**
	 * RXgN^
	 */
	public CodeMasterCardAction() {
		super();
	}

	/**
	 * ANV
	 */
	public void action() throws Exception {
		// DBRlNV擾
		getConnection();
		// SYSTEMmF
		confirmSystemAuth();
		// VO̎擾yѐݒ
		CodeMasterCardVo vo = new CodeMasterCardVo();
		vo.initVo(cfg, msg, cmd, aspUser, user);
		vo.setParams(request);
		// VOyуtH[hURL̐ݒ
		setVo(vo);
		setUrl(vo.getRetUrl());
		// DAȌ
		MCodeDao dao = new MCodeDao();
		dao.initDao(cfg, cmd, aspUser, user, conn);
		// R[h敪v_EXg쐬
		vo.aryPltTId = getMosPCodeArray();
		// DTO̎擾
		MCodeDto dto;
		Object obj = session.getAttribute(MospConst.ATT_DTO);
		dto = obj instanceof MCodeDto ? (MCodeDto)obj : null;
		// R}h̏
		if (cmd.equals(CMD_CODE_CARD_SHOW)) {
			// \(VK)
			vo.setPltTId("");
			vo.setTxtTCode("");
			vo.setTxtTName("");
			vo.setTxtTChange("");
			vo.setMode(CodeMasterCardVo.MODE_INSERT);
		} else if (cmd.equals(CMD_CODE_CARD_SELECT)) {
			// \(L[ŏ)
			// f[^̎擾
			dto = dao.findForKey(key1, key2);
			chkExist(dto);
			// VOɏZbg
			vo.setFields(dto);
			setMode(vo);
			// ZbVDTOZbg
			session.setAttribute(MospConst.ATT_DTO, dto);
		} else if (cmd.equals(CMD_CODE_CARD_INSERT)) {
			// VKo^
			dto = insert(vo);
			// ZbVDTOZbg
			session.setAttribute(MospConst.ATT_DTO, dto);
		} else if (cmd.equals(CMD_CODE_CARD_UPDATE)) {		
			// XV
			dto = update(vo, dto);
			// ZbVDTOZbg
			session.setAttribute(MospConst.ATT_DTO, dto);
		} else if (cmd.equals(CMD_CODE_CARD_DELETE)) {
			// 폜
			dto = delete(vo, dto);
			// ZbVDTOZbg
			session.setAttribute(MospConst.ATT_DTO, dto);
		} else {
			throw new MospException(MospConst.EX_CMD_INVALID);
		}
	}

	/**
	 * f[^}
	 * @param vo ΏVO
	 * @return f[^}ΏDTO
	 * @throws Exception
	 */
	private MCodeDto insert(CodeMasterCardVo vo) throws Exception {
		// p[^̑ÓmF
		vo.validate(true);
		// DAȌ
		MCodeDao dao = new MCodeDao();
		dao.initDao(cfg, cmd, aspUser, user, conn);
		// ݃`FbN
		chkDuplicate(dao.findForKey(vo.getPltTId(), vo.getTxtTCode()), vo);
		// DTȌ
		MCodeDto dto = new MCodeDto();
		vo.setDtoFields(dto);
		// f[^̑}
		dao.insert(dto);
		// DTO̍Ď擾
		dto = dao.findForKey(dto.getTId(), dto.getTCode());
		chkInsert(dto);
		// R~bg
		commit();
		// [hݒ
		setMode(vo);
		// bZ[Wݒ
		vo.setMessage(MospUtility.getMessage(msg, MospConst.MSG_INSERT, ""));
		return dto;
	}

	/**
	 * f[^XV
	 * @param vo ΏVO
	 * @param dto ΏDTO
	 * @return f[^}ΏDTO
	 * @throws Exception
	 */
	private MCodeDto update(CodeMasterCardVo vo, MCodeDto dto) throws Exception {
		// R[h敪擾
		vo.setPltTId(dto.getTId());
		vo.setTxtTCode(dto.getTCode());
		// p[^̑ÓmF
		vo.validate(false);
		// DAȌ
		MCodeDao dao = new MCodeDao();
		dao.initDao(cfg, cmd, aspUser, user, conn);
		// rmF
		chkExclusive(dao.findForKey(dto.getTId(), dto.getTCode()), dao.findForUpdate(dto.getTId(), dto.getTCode()), vo);
		// DTȌ
		vo.setDtoFields(dto);
		// f[^̍XV
		dao.update(dto);
		// DTO̍Ď擾
		MCodeDto retDto = dao.findForKey(dto.getTId(), dto.getTCode());
		chkUpdate(retDto);
		// R~bg
		commit();
		// [hݒ
		setMode(vo);
		// bZ[Wݒ
		vo.setMessage(MospUtility.getMessage(msg, MospConst.MSG_UPDATE, ""));
		return retDto;
	}

	/**
	 * f[^폜
	 * @param vo ΏVO
	 * @param dto ΏDTO
	 * @return f[^}ΏDTO
	 * @throws Exception
	 */
	private MCodeDto delete(CodeMasterCardVo vo, MCodeDto dto) throws Exception {
		// DAȌ
		MCodeDao dao = new MCodeDao();
		dao.initDao(cfg, cmd, aspUser, user, conn);
		// rmF
		chkExclusive(dao.findForKey(dto.getTId(), dto.getTCode()), dao.findForUpdate(dto.getTId(), dto.getTCode()), vo);
		// f[^̍폜
		dao.delete(dto);
		// DTO̍Ď擾
		MCodeDto retDto = dao.findForKey(dto.getTId(), dto.getTCode());
		// R~bg
		commit();
		// [hݒ
		vo.setMode(CodeMasterCardVo.MODE_INSERT);
		// bZ[Wݒ
		vo.setMessage(MospUtility.getMessage(msg, MospConst.MSG_DELETE, ""));
		return retDto;
	}

	/**
	 * [hݒ
	 * @param vo ΏVO
	 * @throws Exception
	 */
	private void setMode(CodeMasterCardVo vo) throws Exception {
		// [hݒ
		if (hasSystemAuth()) {
			vo.setMode(CodeMasterCardVo.MODE_SYSTEM);
		} else {
			vo.setMode(CodeMasterCardVo.MODE_UPDATE);
		}
	}

}
